==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/lang/ku.js <==
﻿/**
 * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

/**
 * @fileOverview
 */

/**#@+
   @type String
   @example
*/

/**
 * Contains the dictionary of language entries.
 * @namespace
 */
CKEDITOR.lang[ 'ku' ] = {
	// ARIA description.
	editor: 'سەرنووسەی دەقی بە پیت',
	editorPanel: 'Rich Text Editor panel', // MISSING

	// Common messages and labels.
	common: {
		// Screenreader titles. Please note that screenreaders are not always capable
		// of reading non-English words. So be careful while translating it.
		editorHelp: 'کلیکی ALT لەگەڵ 0 بکه‌ بۆ یارمەتی',

		browseServer: 'هێنانی ڕاژە',
		url: 'ناونیشانی بەستەر',
		protocol: 'پڕۆتۆکۆڵ',
		upload: 'بارکردن',
		uploadSubmit: 'ناردنی بۆ ڕاژە',
		image: 'وێنە',
		flash: 'فلاش',
		form: 'داڕشتە',
		checkbox: 'خانەی نیشانکردن',
		radio: 'جێگرەوەی دوگمە',
		textField: 'خانەی دەق',
		textarea: 'ڕووبەری دەق',
		hiddenField: 'شاردنەوی خانە',
		button: 'دوگمە',
		select: 'هەڵبژاردەی خانە',
		imageButton: 'دوگمەی وێنە',
		notSet: '<هیچ دانەدراوە>',
		id: 'ناسنامە',
		name: 'ناو',
		langDir: 'ئاراستەی زمان',
		langDirLtr: 'چەپ بۆ ڕاست (LTR)',
		langDirRtl: 'ڕاست بۆ چەپ (RTL)',
		langCode: 'هێمای زمان',
		longDescr: 'پێناسەی درێژی بەستەر',
		cssClass: 'شێوازی چینی په‌ڕە',
		advisoryTitle: 'ڕاوێژکاری سەردێڕ',
		cssStyle: 'شێواز',
		ok: 'باشە',
		cancel: 'هەڵوەشاندن',
		close: 'داخستن',
		preview: 'پێشبینین',
		resize: 'گۆڕینی ئەندازە',
		generalTab: 'گشتی',
		advancedTab: 'پەرەسەندوو',
		validateNumberFailed: 'ئەم نرخە ژمارە نیە، تکایە نرخێکی ژمارە بنووسە.',
		confirmNewPage: 'سەرجەم گۆڕانکاریەکان و پێکهاتەکانی ناووەوە لەدەست دەدەی گەر بێتوو پاشکەوتی نەکەی یەکەم جار، تۆ هەر دڵنیایی لەکردنەوەی پەنجەرەکی نوێ؟',
		confirmCancel: 'هەندێك هەڵبژاردە گۆڕدراوە. تۆ دڵنیایی لە داخستنی ئەم دیالۆگە؟',
		options: 'هەڵبژاردەکان',
		target: 'ئامانج',
		targetNew: 'پەنجەرەیەکی نوێ (_blank)',
		targetTop: 'لووتکەی پەنجەرە (_top)',
		targetSelf: 'لەهەمان پەنجەرە (_self)',
		targetParent: 'پەنجەرەی باوان (_parent)',
		langDirLTR: 'چەپ بۆ ڕاست (LTR)',
		langDirRTL: 'ڕاست بۆ چەپ (RTL)',
		styles: 'شێواز',
		cssClasses: 'شێوازی چینی پەڕە',
		width: 'پانی',
		height: 'درێژی',
		align: 'ڕێککەرەوە',
		alignLeft: 'چەپ',
		alignRight: 'ڕاست',
		alignCenter: 'ناوەڕاست',
		alignJustify: 'هاوستوونی',
		alignTop: 'سەرەوە',
		alignMiddle: 'ناوەند',
		alignBottom: 'ژێرەوە',
		alignNone: 'None', // MISSING
		invalidValue	: 'نرخێکی نادرووست.',
		invalidHeight: 'درێژی دەبێت ژمارە بێت.',
		invalidWidth: 'پانی دەبێت ژمارە بێت.',
		invalidCssLength: 'ئەم نرخەی دراوە بۆ خانەی "%1" دەبێت ژمارەکی درووست بێت یان بێ ناونیشانی ئامرازی (px, %, in, cm, mm, em, ex, pt, یان pc).',
		invalidHtmlLength: 'ئەم نرخەی دراوە بۆ خانەی "%1" دەبێت ژمارەکی درووست بێت یان بێ ناونیشانی ئامرازی HTML (px یان %).',
		invalidInlineStyle: 'دانەی نرخی شێوازی ناوهێڵ دەبێت پێکهاتبێت لەیەك یان زیاتری داڕشتە "ناو : نرخ", جیاکردنەوەی بە فاریزە و خاڵ',
		cssLengthTooltip: 'ژمارەیەك بنووسه‌ بۆ نرخی piksel یان ئامرازێکی درووستی CSS (px, %, in, cm, mm, em, ex, pt, یان pc).',

		// Put the voice-only part of the label in the span.
		unavailable: '%1<span class="cke_accessibility">, ئامادە نیە</span>'
	}
};

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/lang/ku.js <==
/**
 * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

/**
 * @fileOverview
 */

/**#@+
   @type String
   @example
*/

/**
 * Contains the dictionary of language entries.
 * @namespace
 */
CKEDITOR.lang[ 'ku' ] = {
	// ARIA description.
	editor: 'سەرنووسەی دەقی تەواو',
	editorPanel: 'بڕگەی سەرنووسەی دەقی تەواو',

	// Common messages and labels.
	common: {
		// Screenreader titles. Please note that screenreaders are not always capable
		// of reading non-English words. So be careful while translating it.
		editorHelp: 'کلیکی ALT لەگەڵ 0 بکه‌ بۆ یارمەتی',

		browseServer: 'هێنانی ڕاژە',
		url: 'ناونیشانی بەستەر',
		protocol: 'پڕۆتۆکۆڵ',
		upload: 'بارکردن',
		uploadSubmit: 'ناردنی بۆ ڕاژە',
		image: 'وێنە',
		flash: 'فلاش',
		form: 'داڕشتە',
		checkbox: 'خانەی نیشانکردن',
		radio: 'جێگرەوەی دوگمە',
		textField: 'خانەی دەق',
		textarea: 'ڕووبەری دەق',
		hiddenField: 'شاردنەوی خانە',
		button: 'دوگمە',
		select: 'هەڵبژاردەی خانە',
		imageButton: 'دوگمەی وێنە',
		notSet: '<هیچ دانەدراوە>',
		id: 'ناسنامە',
		name: 'ناو',
		langDir: 'ئاراستەی زمان',
		langDirLtr: 'چەپ بۆ ڕاست (LTR)',
		langDirRtl: 'ڕاست بۆ چەپ (RTL)',
		langCode: 'هێمای زمان',
		longDescr: 'پێناسەی درێژی بەستەر',
		cssClass: 'شێوازی چینی په‌ڕە',
		advisoryTitle: 'ڕاوێژکاری سەردێڕ',
		cssStyle: 'شێواز',
		ok: 'باشە',
		cancel: 'پاشگەزبوونەوە',
		close: 'داخستن',
		preview: 'پێشبینین',
		resize: 'گۆڕینی ئەندازە',
		generalTab: 'گشتی',
		advancedTab: 'پەرەسەندوو',
		validateNumberFailed: 'ئەم نرخە ژمارە نیە، تکایە نرخێکی ژمارە بنووسە.',
		confirmNewPage: 'سەرجەم گۆڕانکاریەکان و پێکهاتەکانی ناووەوە لەدەست دەدەی گەر بێتوو پاشکەوتی نەکەی یەکەم جار، تۆ هەر دڵنیایی لەکردنەوەی پەنجەرەکی نوێ؟',
		confirmCancel: 'هەندێك هەڵبژاردە گۆڕدراوە. تۆ دڵنیایی لە داخستنی ئەم دیالۆگە؟',
		options: 'هەڵبژاردەکان',
		target: 'ئامانج',
		targetNew: 'پەنجەرەیەکی نوێ (_blank)',
		targetTop: 'لووتکەی پەنجەرە (_top)',
		targetSelf: 'لەهەمان پەنجەرە (_self)',
		targetParent: 'پەنجەرەی باوان (_parent)',
		langDirLTR: 'چەپ بۆ ڕاست (LTR)',
		langDirRTL: 'ڕاست بۆ چەپ (RTL)',
		styles: 'شێواز',
		cssClasses: 'شێوازی چینی پەڕە',
		width: 'پانی',
		height: 'درێژی',
		align: 'ڕێککەرەوە',
		alignLeft: 'چەپ',
		alignRight: 'ڕاست',
		alignCenter: 'ناوەڕاست',
		alignJustify: 'هاوستوونی',
		alignTop: 'سەرەوە',
		alignMiddle: 'ناوەند',
		alignBottom: 'ژێرەوە',
		alignNone: 'هیچ',
		invalidValue	: 'نرخێکی نادرووست.',
		invalidHeight: 'درێژی دەبێت ژمارە بێت.',
		invalidWidth: 'پانی دەبێت ژمارە بێت.',
		invalidCssLength: 'ئەم نرخەی دراوە بۆ خانەی "%1" دەبێت ژمارەکی درووست بێت یان بێ ناونیشانی ئامرازی (px, %, in, cm, mm, em, ex, pt, یان pc).',
		invalidHtmlLength: 'ئەم نرخەی دراوە بۆ خانەی "%1" دەبێت ژمارەکی درووست بێت یان بێ ناونیشانی ئامرازی HTML (px یان %).',
		invalidInlineStyle: 'دانەی نرخی شێوازی ناوهێڵ دەبێت پێکهاتبێت لەیەك یان زیاتری داڕشتە "ناو : نرخ", جیاکردنەوەی بە فاریزە و خاڵ',
		cssLengthTooltip: 'ژمارەیەك بنووسه‌ بۆ نرخی piksel یان ئامرازێکی درووستی CSS (px, %, in, cm, mm, em, ex, pt, یان pc).',

		// Put the voice-only part of the label in the span.
		unavailable: '%1<span class="cke_accessibility">, ئامادە نیە</span>'
	}
};
